@@ -8,12 +8,15 @@ class RunCommand(Command):
     help = 'Runs an arbitrary command in the clickable container'
 
     def run(self, path_arg=None):
-        if not path_arg:
-            raise ClickableException('No command supplied for `clickable run`')
+        cmd = path_arg
+        if not cmd:
+            cmd = "bash"
 
         self.config.container.setup()
-        self.config.container.run_command(path_arg,
+        self.config.container.run_command(
+            cmd,
             use_build_dir=False,
             tty=True,
             localhost=True,
+            root_user=True,
         )
